![pywhiten logo](pywhitenlogo3.png)

A python package for conducting Lomb-Scargle-based pre-whitening of stellar time series. A similar program, called pypw,
was written and utilized for the analyses presented in my Master's thesis. I'm in the process of converting pypw to
this package, such that it can be utilized in a more accessible fashion.

Current Status (18 Mar 2023):

Core behaviour of pypw re-implemented in this package. Need to do a bit of final testing and upload to pip, then write some usage instructions here. Stay tuned.

Expected completion: By 2 Mar, 2023
